==> ceph-provisioners-2024.2.95+6b985e51b.tgz: ceph-provisioners/CHANGELOG.md <==
# Release notes

## 2024.2.0-40

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Validate each storageclass created
- 0.1.3 Uplift from Nautilus to Octopus release
- 0.1.4 Add Ceph CSI plugin
- 0.1.5 Fix Helm tests for the Ceph provisioners
- 0.1.6 Update ceph_mon config as per new ceph clients
- 0.1.7 Use full image ref for docker official images
- 0.1.8 Enable Ceph CSI Provisioner to Stand Alone
- 0.1.10 Add check for empty ceph endpoint
- 0.1.11 Limit Ceph Provisioner Container Security Contexts
- 0.1.12 Add ceph mon v2 port for ceph csi provisioner
- 0.1.13 Fix ceph-provisioner rbd-healer error
- 0.1.14 Helm 3 - Fix Job labels
- 0.1.15 Add support to connect to rook-ceph cluster
- 0.1.16 Update htk requirements
- 0.1.17 Consolidate mon_endpoints discovery
- 0.1.18 Update CSI images & fix ceph csi provisioner RBAC
- 0.1.19 Add pods watch and list permissions to cluster role
- 0.1.20 Add missing CRDs for volume snapshots (classes, contents)
- 0.1.21 Added OCI registry authentication
- 0.1.22 Remove legacy Ceph provisioners
- 0.1.23 Remove unnecessary templates
- 0.1.24 Update all Ceph images to Focal
- 0.1.25 Update kubernetes registry to registry.k8s.io
- 0.1.26 Update Ceph to 17.2.6
- 0.1.27 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.28 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.29 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.30 Specify CSI drivername in values.yaml
- 0.1.31 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.32 Update ceph_rbd_provisioner image to 18.2.2
- 0.1.33 Remove dependencies on legacy provisioners
- 0.1.34 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> ceph-provisioners-2025.1.1+35052e51b.tgz: ceph-provisioners/CHANGELOG.md <==
# Release notes

## 2025.1.0-83

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Validate each storageclass created
- 0.1.3 Uplift from Nautilus to Octopus release
- 0.1.4 Add Ceph CSI plugin
- 0.1.5 Fix Helm tests for the Ceph provisioners
- 0.1.6 Update ceph_mon config as per new ceph clients
- 0.1.7 Use full image ref for docker official images
- 0.1.8 Enable Ceph CSI Provisioner to Stand Alone
- 0.1.10 Add check for empty ceph endpoint
- 0.1.11 Limit Ceph Provisioner Container Security Contexts
- 0.1.12 Add ceph mon v2 port for ceph csi provisioner
- 0.1.13 Fix ceph-provisioner rbd-healer error
- 0.1.14 Helm 3 - Fix Job labels
- 0.1.15 Add support to connect to rook-ceph cluster
- 0.1.16 Update htk requirements
- 0.1.17 Consolidate mon_endpoints discovery
- 0.1.18 Update CSI images & fix ceph csi provisioner RBAC
- 0.1.19 Add pods watch and list permissions to cluster role
- 0.1.20 Add missing CRDs for volume snapshots (classes, contents)
- 0.1.21 Added OCI registry authentication
- 0.1.22 Remove legacy Ceph provisioners
- 0.1.23 Remove unnecessary templates
- 0.1.24 Update all Ceph images to Focal
- 0.1.25 Update kubernetes registry to registry.k8s.io
- 0.1.26 Update Ceph to 17.2.6
- 0.1.27 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.28 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.29 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.30 Specify CSI drivername in values.yaml
- 0.1.31 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.32 Update ceph_rbd_provisioner image to 18.2.2
- 0.1.33 Remove dependencies on legacy provisioners
- 0.1.34 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
